//
//  	ASYNC.HPP
//	version 1.00	11/15/91
//	header for ASYNC.CPP async communications class
//	copyright (c) 1991 by James S. Clark
//	all rights reserved
//

#ifndef ASYNC_HPP
#define ASYNC_HPP

// 	baudrate divisor values (115200 / bits per second)

#define COM110      0x417           // 110 baud
#define COM150      0x300           // 150 baud
#define COM300      0x180           // 300 baud
#define COM600      0x0c0           // 600 baud
#define COM1200     0x060           // 1200 baud
#define COM2400     0x030           // 2400 baud
#define COM4800     0x018           // 4800 baud
#define COM9600     0x00c           // 9600 baud
#define COM19200    0x006           // 19200 baud
#define COM38400    0x003           // 38400 baud

// 	line control register definitions

#define COMWORD5    0               // 5 bit word
#define COMWORD6    1               // 6 bit word
#define COMWORD7    2               // 7 bit word
#define COMWORD8    3               // 8 bit word

#define COMSTOP1    0               // 1 stop bit
#define COMSTOP2    4               // 2 stop bit

#define COMPARNONE  0               // no parity
#define COMPARODD   8               // odd parity
#define COMPAREVEN  24              // even parity

#define COMSBREAK   0x40            // raise break signal

// 	port specific values

#define COM1VECTOR  0x0c            // interrupt vector number for COM1:
#define COM2VECTOR  0x0b            // interrupt vector number for COM2:

#define COM1PORT    0x03f8          // port address for COM1:
#define COM2PORT    0x02f8          // port address for COM2:
#define COM3PORT    0x03e8          // port address for COM3:
#define COM4PORT    0x02e8          // port address for COM4:

#define COM1MASK    0x010           // IRQ mask to disable for COM1:
#define COM2MASK    0x008           // for COM2:

// 	modem control register bits

#define COMDTR      0x01            // modem control bits
#define COMRTS      0x02
#define COMOUT2     0x08            // enable interrupt

// 	modem status register bits

#define COMDCD      0x80            // data carrier detect
#define COMRING     0x40            // ring
#define COMDSR      0x20            // data set ready
#define COMCTS      0x10            // clear to send
#define COMENDRING  0x04            // trailing edge of ring

// 	line status register bits

#define COMBREAK    0x10            // break detected
#define COMFRAME    0x08            // framing error
#define COMPARITY   0x04            // parity error
#define COMOVERRUN  0x02            // overrun error
#define COMLINEERROR (COMFRAME | COMPARITY | COMOVERRUN)

// 	special characters

#define XON         0x11            // XON  (DC1) character
#define XOFF        0x13            // XOFF (DC3) character


//	global variables

#ifndef comlinestatus
	extern unsigned int  comdebug;		// JSC
	extern unsigned int  comport;
	extern unsigned int  combaudrate;
	extern unsigned char comlinecontrol;
	extern unsigned char comlinestatus;
	extern unsigned char commodemcontrol;
	extern unsigned char commodemstatus;

	extern unsigned int  comibufsz;
	extern unsigned int  comibufcnt;
	extern long int      comitotchars;
	extern unsigned int  comibufmaxused;
	extern unsigned int  comibuftimesfull;

	extern unsigned int  comobufsz;
	extern unsigned int  comobufcnt;
	extern long int      comototchars;
	extern unsigned int  comobufmaxused;
	extern unsigned int  comobuftimesfull;

	extern long int      combitspersecond;
	extern long int      comcharspersecond;
#endif


//	function prototypes

// #define Async::init(port, baud, wsz, pty, sbit, ib, ob)    Async::open(port, baud, wsz | pty | sbit, ib, ob)

class   Async {
public:
	void 	open(unsigned int  port,    // port COM1PORT or COM2PORT
		     unsigned int  baud,    // a COMnnnnn baudrate
		     unsigned char config,  // wordsize, parity, stopbits
		     unsigned int  ibufsz,  // size of input buffer wanted
		     unsigned int  obufsz); // size of output buffer wanted
	void 	changeconfig(unsigned int baud, int config);
	void 	close(void);
	void 	quiesce(void);
	void 	unquiesce(void);
	void 	dropDTR(void);
	void 	raiseDTR(void);
	void 	dropRTS(void);
	void 	raiseRTS(void);

	void 	raisebreak(void);           // starts sending break signal
	void 	dropbreak(void);            // stops  sending break signal

	void 	flushibuf(void);            // flush the input buffer
	void 	flushobuf(void);            // flush the output buffer

	void 	putc(unsigned int ch);      // send out a character
	void 	puts(char *str);            // send out a string
	void 	putxonxoff(int ch);         // put a character (like xon/xoff)
					    // first, before anything in the buffer
	int  	getc(int wait);             // return next char or -1 if none
					    // wait in 1/10 seconds
	void 	waitonobuf();               // wait on output buffer

	void 	debug(char ch);	    		// JSC output ch to logfile
};

#endif
